@@ -1,9 +1,10 @@
 from seatsio.charts.chartsClient import ChartsClient
+from seatsio.eventlog.eventLogClient import EventLogClient
 from seatsio.events.eventsClient import EventsClient
 from seatsio.holdtokens.HoldTokenClient import HoldTokensClient
 from seatsio.httpClient import HttpClient
 from seatsio.reports.usage.usageReports import UsageReports
-from seatsio.subaccounts.subaccountsClient import SubaccountsClient
+from seatsio.seasons.seasonsClient import SeasonsClient
 from seatsio.workspaces.workspacesClient import WorkspacesClient
 
 
@@ -14,7 +15,8 @@ class Client:
         self.http_client = HttpClient(base_url, secret_key, workspace_key, max_retries)
         self.charts = ChartsClient(self.http_client)
         self.events = EventsClient(self.http_client)
-        self.subaccounts = SubaccountsClient(self.http_client)
+        self.seasons = SeasonsClient(self.http_client, self)
         self.workspaces = WorkspacesClient(self.http_client)
         self.hold_tokens = HoldTokensClient(self.http_client)
         self.usage_reports = UsageReports(self.http_client)
+        self.event_log = EventLogClient(self.http_client)
