@@ -1,6 +1,5 @@
-from seatsio.domain import UsageSummaryForAllMonths, UsageDetailsForEventInMonth
-
-from seatsio.domain import UsageDetailsForMonth
+from seatsio.domain import UsageDetailsForMonth, UsageDetailsForEventInMonth
+from seatsio.domain import UsageSummaryForAllMonths
 
 
 class UsageReports:
@@ -9,16 +8,16 @@ class UsageReports:
         self.http_client = http_client
 
     def summary_for_all_months(self):
-        url = "/reports/usage"
+        url = "/reports/usage?version=2"
         body = self.http_client.url(url).get()
         return UsageSummaryForAllMonths(body)
 
     def details_for_month(self, month):
         url = "/reports/usage/month/" + month.serialize()
         body = self.http_client.url(url).get()
-        return UsageDetailsForMonth(body)
+        return UsageDetailsForMonth.from_json(body)
 
     def details_for_event_in_month(self, event_id, month):
         url = "/reports/usage/month/" + month.serialize() + "/event/" + str(event_id)
         body = self.http_client.url(url).get()
-        return UsageDetailsForEventInMonth(body)
+        return UsageDetailsForEventInMonth.from_json(body)
